cd ~/Downloads
sudo apt install software-properties-common apt-transport-https
sudo wget -q https://packages.microsoft.com/keys/microsoft.asc -O- | sudo apt-key add –
sudo add-apt-repository “deb [arch=amd64] https://packages.microsoft.com/repos/vscode stable main”
sudo apt update
sudo apt install code